@@ -1,6 +1,5 @@
 import hashlib
 import os
-import platform
 from assertpy import assert_that
 from typing import Dict, List, Union
 from pathlib import Path
@@ -11,10 +10,11 @@ from deepdriver.sdk.data_types.run import Run, get_run
 from deepdriver.sdk.data_types.table import Table
 from deepdriver.sdk.interface import interface
 from deepdriver.sdk.interface.grpc_interface_pb2 import ArtifactEntry as grpc_ArtifactEntry
+from deepdriver import logger
 
 class ArtifactEntry:
 
-    def __init__(self, path: str, local_path: str, size: int, digest: str):
+    def __init__(self, path: str, local_path: str, size: int, digest: str, status: str):
         assert_that(path).is_not_none()
         assert_that(local_path).is_not_none()
 
@@ -32,35 +32,33 @@ class ArtifactEntry:
         # 파일의 digest 값
         self.digest = digest
 
+        # 파일의 상태(로컬과의 비교)
+        self.status = status
+
     # ArtifactEntry 객체를 기반으로 파일 다운로드 수행
-    def download(self, local_root_path: str, artifact_id: int):
+    def download(self, local_root_path: str, artifact_id: int, file_index: int, total_file_count:int ):
         assert_that(local_root_path).is_not_none()
         assert_that(artifact_id).is_not_none()
 
-        if platform.system() == "Windows":
-            # OS가 윈도우인 경우 path seperator 를 "/"로 통일시켜줌.
-            local_path = os.path.join(local_root_path, self.path.replace("/", os.path.sep))
-        else:
-            local_path = os.path.join(local_root_path, self.path)
-
+        local_path = os.path.join(local_root_path, self.path)
 
         i_last_separator = len(local_path) - local_path[::-1].find(os.path.sep) - 1
         Path(local_path[:i_last_separator]).mkdir(parents=True, exist_ok=True)
 
-        interface.download_file(self.path, artifact_id, local_path)
+        interface.download_file(self.path, artifact_id, local_path, file_index, total_file_count, self.size)
 
         # 다운로드 완료 후 local_path 설정
         self.local_path = local_path
 
     # ArtifactEntry 객체를 기반으로 파일 업로드 수행
-    def upload(self, upload_type: str, root_path: str, run_id: int, artifact_id: int, last_file_yn: str, teamName: str, expName: str, artifact_name: str, artifact_type: str, artifact_digest: str, entry_list: List[grpc_ArtifactEntry]) -> bool:
+    def upload(self, upload_type: str, root_path: str, run_id: int, artifact_id: int, last_file_yn: str, teamName: str, expName: str, artifact_name: str, artifact_type: str, artifact_digest: str, entry_list: List[grpc_ArtifactEntry], file_index:int) -> bool:
         assert_that(root_path).is_not_none()
         assert_that(run_id).is_not_none()
         assert_that(artifact_id).is_not_none()
         assert_that(last_file_yn).is_not_none()
         assert_that(artifact_digest).is_not_none()
         assert_that(entry_list).is_not_none()
-        return interface.upload_file( upload_type, self.local_path, root_path, self.path, run_id, artifact_id, last_file_yn, teamName, expName, artifact_name, artifact_type, artifact_digest, self.digest, entry_list)
+        return interface.upload_file( upload_type, self.local_path, root_path, self.path, run_id, artifact_id, last_file_yn, teamName, expName, artifact_name, artifact_type, artifact_digest, self.digest, entry_list, file_index=file_index)
 
     def __str__(self) -> str:
         return f"{{path:{self.path},local_path:{self.local_path}}}"
@@ -98,6 +96,9 @@ class Artifacts:
             data = os.path.join(".", data) # Prefix with a dot
         self.__add(data, name)
 
+        # local 파일의 존재여부를 판단하여 "DELETE" 상태로 마킹
+        self.__local_path_sync_for_delete()
+
     def __add(self, data: Union[str, Table, Image, Chart], name: str=None, depth: int=0) -> None:
         # data에 str가 들어오면 file 인지, dir 인지 reference url(http:// or s3:// ..) 인지 체크
         if isinstance(data, str):
@@ -122,12 +123,33 @@ class Artifacts:
                 size = os.stat(local_path).st_size
                 with open(local_path,"rb") as f:
                     digest = hashlib.md5(f.read()).hexdigest()
-                self.entry_list.append(ArtifactEntry(path, local_path, size, digest))
+
+                entry = self.__find_entry_by_local_path(local_path)
+                if entry:
+                    entry.status = "SYNC"   # 변경이 없는 경우
+                else:
+                    self.entry_list.append(ArtifactEntry(path, local_path, size, digest, status="ADD"))  # 파일이 추가된 경우
+
+    def __local_path_sync_for_delete(self) -> None:
+        # local에서 삭제된 파일의 status를 "DELETE"로 변경
+        for entry in self.entry_list:
+            if entry.status == "ADD":   # 상태가 "ADD"인 entry만 확인
+                if not os.path.isfile(entry.local_path):
+                    entry.status = "DELETE"
+
+    def __find_entry_by_local_path(self, local_path:str) -> ArtifactEntry:
+        for entry in self.entry_list:
+            if entry.local_path == local_path:
+                return entry
+        else:
+            return None
+
+
 
     # Artifact의 정보를 전송하고, ArtifactEntry 각각의 파일을 전송한다
     def upload(self) -> bool:
         # Interface.py의 upoad_artifact ( grpc_interface.py의 upoad_artifact)를 호출 하여 artifact 정보에 대해 전송
-        entry_dict = {entry.path.replace("\\", "/"): entry for entry in self.entry_list}
+        entry_dict = {entry.path: entry for entry in self.entry_list}
         entry_list: List(grpc_ArtifactEntry) = []
         hasher = hashlib.md5()
         #TODO: 상태에 따라서 status 변경
@@ -154,7 +176,8 @@ class Artifacts:
                 upload_type = "ARTI_REPO"
             else:
                 upload_type = "ARTI_FILES"
-            succeeded = entry.upload(upload_type, root_path, self.run.run_id, self.id, last_file_yn,  self.run.team_name, self.run.exp_name, self.name, self.type, artifact_digest, entry_list)
+
+            succeeded = entry.upload(upload_type, root_path, self.run.run_id, self.id, last_file_yn,  self.run.team_name, self.run.exp_name, self.name, self.type, artifact_digest, entry_list, file_index=i)
             if not succeeded:
                 return False
         return True
@@ -165,8 +188,8 @@ class Artifacts:
         local_root_path = os.path.join(".", "deepdriver", "artifact", str(self.id))
 
         # Artifact 객체가 가진 entry_list 의  ArtifactEntry.download()를 각각 호출
-        for entry in self.entry_list:
-            entry.download(local_root_path, self.id)
+        for idx, entry in enumerate(self.entry_list):
+            entry.download(local_root_path, self.id, idx, total_file_count=len(self.entry_list))
         return local_root_path
 
     def __str__(self) -> str:
