@@ -3,7 +3,7 @@ from __future__ import annotations
 import time
 from assertpy import assert_that
 from typing import Dict, Tuple, TYPE_CHECKING
-
+from deepdriver import logger
 from deepdriver.sdk import util
 from deepdriver.sdk.interface import interface
 from deepdriver.sdk.interface.grpc_interface_pb2 import *
@@ -45,7 +45,20 @@ class Run:
 
         # item에 key값이 “timestamp” 이고 value가 현재시각 (time.time())인 item도 추가
         # item에 로그의 key value값의 쌍이 들어가도록 item을 추가ex) log({“loss” :0.03, “acc” :0.97}) -> key가 loss 이고 value가 0.03인 item과 key가 acc이고 value가 0.97인 item이 추가됨
-        # TODO value값이 Image, Table, Chart 인경우 value값에 각 객체를 json으로 변환한 값을 추가한다.( 각 객체의 to_json호출)
+        # TODO : value값이 Image, Table, Chart 인경우 value값에 각 객체를 json으로 변환한 값을 추가한다.( 각 객체의 to_json호출) ##
+        from deepdriver.sdk.data_types.table import Table
+
+
+        for key, value in data.items():
+            # TODO: Image, Chart등 다른 데이터 형식도 추가해야함
+            if isinstance(value, Table):
+                data[key] = value.to_json(key)
+                logger.debug(f"Bable을 str(json)로 변환 변환 : {data[key]}")
+                # TODO : Upload File
+                value.upload_file(self, key)
+
+
+
         data["timestamp"] = time.time()
 
         # Item의 key, value에 각각 하기의 정보를 넣는다
